@@ -1,5 +1,10 @@
 require 'spec_helper'
 
+if ENV['AUTOPKGTEST_TEST_ARCH'] == 'riscv64'
+  puts "Skipping this test because it is unreliable on riscv64."
+  exit 77
+end
+
 describe service('varnish') do
 # Disable this check because ruby-specinfra is broken and only checks for
 # the init script or the Upstart service.
