@@ -1,5 +1,10 @@
 require 'spec_helper'
 
+if ENV['AUTOPKGTEST_TEST_ARCH'] == 'riscv64'
+  puts "Skipping this test because it is unreliable on riscv64."
+  exit 77
+end
+
 describe command('/usr/sbin/varnishd -C -f /etc/varnish/default.vcl') do
   its(:exit_status) { should eq 0 }
 end
